import 'package:bolt/bolt.dart';
import 'package:equatable/equatable.dart';

/// {@template connection}
/// Represents a connection between the server and a client.
/// {@endtemplate}
class Connection extends Equatable {
  /// {@macro connection}
  const Connection({
    required this.clientSalt,
    required this.serverSalt,
    required this.address,
  });

  /// The salt received from the client.
  final int clientSalt;

  /// The salt generated by the server.
  final int serverSalt;

  /// The address of the client.
  final Address address;

  /// The xor of the client and server salt.
  int get salt => clientSalt ^ serverSalt;

  @override
  List<Object> get props => [clientSalt, serverSalt, address];

  @override
  String toString() {
    return 'Connection { address: $address }';
  }
}
